@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.h,v 1.44 2005/05/31 14:36:51 chpe Exp $
+ *  $Id: EphyBrowser.h,v 1.47 2005/08/27 19:23:42 chpe Exp $
  */
 
 #ifndef EPHY_BROWSER_H
@@ -34,6 +34,7 @@
 #include <nsIWebNavigation.h>
 #include <nsISHistory.h>
 #include <nsIWebBrowser.h>
+#include <nsIWebBrowserFocus.h>
 #include <nsIDOMDocument.h>
 #include <nsIDOMWindow.h>
 #include <nsIPrintSettings.h>
@@ -158,14 +159,6 @@ public:
 	nsresult GetSHUrlAtIndex (PRInt32 index, nsACString &url);
 	nsresult GoToHistoryIndex (PRInt16 index);
 
-#ifndef HAVE_GECKO_1_8
-	enum ReloadType { RELOAD_NORMAL		 = 0,
-			  RELOAD_FORCE		 = 1,
-			  RELOAD_ENCODING_CHANGE = 2 };
-
-	nsresult Reload (ReloadType flags);
-#endif
-
 	nsresult ForceEncoding (const char *encoding);
 	nsresult GetEncoding (nsACString &encoding);
 	nsresult GetForcedEncoding (nsACString &encoding);
@@ -186,10 +179,16 @@ public:
 
         EphyEmbedDocumentType GetDocumentType ();
 
+#ifndef HAVE_GECKO_1_8
+	nsresult FocusActivate ();
+	nsresult FocusDeactivate ();
+#endif /* !HAVE_GECKO_1_8 */
+
 	nsCOMPtr<nsIWebBrowser> mWebBrowser;
 private:
 	GtkWidget *mEmbed;
 
+	nsCOMPtr<nsIWebBrowserFocus> mWebBrowserFocus;
 	nsCOMPtr<nsIDOMDocument> mTargetDocument;
 	nsCOMPtr<nsIDOMEventTarget> mEventTarget;
 	nsCOMPtr<nsIDOMWindow> mDOMWindow;
