@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-toolbar.h,v 1.4 2005/07/26 14:41:39 chpe Exp $
+ *  $Id: ephy-toolbar.h,v 1.5 2005/08/01 15:57:48 chpe Exp $
  */
 
 #ifndef EPHY_TOOLBAR_H
@@ -25,6 +25,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
 
 #include "egg-editable-toolbar.h"
 #include "ephy-window.h"
@@ -65,7 +66,7 @@ GType		ephy_toolbar_get_type			(void);
 EphyToolbar    *ephy_toolbar_new			(EphyWindow *window);
 
 void		ephy_toolbar_set_favicon		(EphyToolbar *toolbar,
-							 const char *icon);
+							 GdkPixbuf *icon);
 
 void		ephy_toolbar_set_show_leave_fullscreen	(EphyToolbar *toolbar,
 							 gboolean show);
